﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/ec2/model/CreateDefaultSubnetRequest.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

using namespace Aws::EC2::Model;
using namespace Aws::Utils;

CreateDefaultSubnetRequest::CreateDefaultSubnetRequest() : 
    m_availabilityZoneHasBeenSet(false),
    m_dryRun(false),
    m_dryRunHasBeenSet(false),
    m_ipv6Native(false),
    m_ipv6NativeHasBeenSet(false)
{
}

Aws::String CreateDefaultSubnetRequest::SerializePayload() const
{
  Aws::StringStream ss;
  ss << "Action=CreateDefaultSubnet&";
  if(m_availabilityZoneHasBeenSet)
  {
    ss << "AvailabilityZone=" << StringUtils::URLEncode(m_availabilityZone.c_str()) << "&";
  }

  if(m_dryRunHasBeenSet)
  {
    ss << "DryRun=" << std::boolalpha << m_dryRun << "&";
  }

  if(m_ipv6NativeHasBeenSet)
  {
    ss << "Ipv6Native=" << std::boolalpha << m_ipv6Native << "&";
  }

  ss << "Version=2016-11-15";
  return ss.str();
}


void  CreateDefaultSubnetRequest::DumpBodyToUrl(Aws::Http::URI& uri ) const
{
  uri.SetQueryString(SerializePayload());
}
