﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/lexv2-models/model/DescribeCustomVocabularyMetadataResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::LexModelsV2::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

DescribeCustomVocabularyMetadataResult::DescribeCustomVocabularyMetadataResult() : 
    m_customVocabularyStatus(CustomVocabularyStatus::NOT_SET)
{
}

DescribeCustomVocabularyMetadataResult::DescribeCustomVocabularyMetadataResult(const Aws::AmazonWebServiceResult<JsonValue>& result) : 
    m_customVocabularyStatus(CustomVocabularyStatus::NOT_SET)
{
  *this = result;
}

DescribeCustomVocabularyMetadataResult& DescribeCustomVocabularyMetadataResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("botId"))
  {
    m_botId = jsonValue.GetString("botId");

  }

  if(jsonValue.ValueExists("botVersion"))
  {
    m_botVersion = jsonValue.GetString("botVersion");

  }

  if(jsonValue.ValueExists("localeId"))
  {
    m_localeId = jsonValue.GetString("localeId");

  }

  if(jsonValue.ValueExists("customVocabularyStatus"))
  {
    m_customVocabularyStatus = CustomVocabularyStatusMapper::GetCustomVocabularyStatusForName(jsonValue.GetString("customVocabularyStatus"));

  }

  if(jsonValue.ValueExists("creationDateTime"))
  {
    m_creationDateTime = jsonValue.GetDouble("creationDateTime");

  }

  if(jsonValue.ValueExists("lastUpdatedDateTime"))
  {
    m_lastUpdatedDateTime = jsonValue.GetDouble("lastUpdatedDateTime");

  }



  return *this;
}
