﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/quicksight/model/UpdateAnalysisResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::QuickSight::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

UpdateAnalysisResult::UpdateAnalysisResult() : 
    m_updateStatus(ResourceStatus::NOT_SET),
    m_status(0)
{
}

UpdateAnalysisResult::UpdateAnalysisResult(const Aws::AmazonWebServiceResult<JsonValue>& result) : 
    m_updateStatus(ResourceStatus::NOT_SET),
    m_status(0)
{
  *this = result;
}

UpdateAnalysisResult& UpdateAnalysisResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("Arn"))
  {
    m_arn = jsonValue.GetString("Arn");

  }

  if(jsonValue.ValueExists("AnalysisId"))
  {
    m_analysisId = jsonValue.GetString("AnalysisId");

  }

  if(jsonValue.ValueExists("UpdateStatus"))
  {
    m_updateStatus = ResourceStatusMapper::GetResourceStatusForName(jsonValue.GetString("UpdateStatus"));

  }

  if(jsonValue.ValueExists("RequestId"))
  {
    m_requestId = jsonValue.GetString("RequestId");

  }



  m_status = static_cast<int>(result.GetResponseCode());

  return *this;
}
